#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Photolab_redlayer python-fu pour Gimp 2.6
# Copyright Raymond Ostertag 2009
# Licence GPL

# Version 1.0
# - initial release

# Installation : put the photolab_redlayer.py file in your $HOME/.gimp-2.n/plug-ins.
# On Linux and Mac OSX the file must be executable.
# Documentation : http://www.gimp.org/docs/python/index.html

from gimpfu import *
import os, glob

# i18n
#
import gettext
locale_directory = gimp.locale_directory
gettext.install( "gimp20-photolab" , locale_directory, unicode=True )

#
Photolab_redlayer_help = _("Add/remove a red layer on top of layers. For colorblind peoples who can not see full intensity of light in red.")                                
Photolab_redlayer_description = Photolab_redlayer_help
#

# constant
#
channelMixerIntensity = 2.0
layerOpacity = 50

# dialog parameters
#
Standalone_parameters = [
  (PF_IMAGE, "inImage", "Input image", None),
  (PF_DRAWABLE, "inLayer", "Input drawable", None),
]
Photolab_redlayer_parameters = [
#put here main script parameters
]  

# main
#                                         
def python_fu_photolab_redlayer( 
  inImage,
  inDrawable,
  ): 
  pdb.gimp_image_undo_group_start( inImage )
  #find if redLayer allready exist
  redLayerExist = False
  layerList = inImage.layers
  for layerID in layerList:
    if layerID.name == "ColorBlindRedLayer":
      redLayerExist = True
      redLayerID = layerID
  if redLayerExist :
    #remove redLayer
    inImage.remove_layer( redLayerID )
  else:
    #add redLayer
    pdb.gimp_edit_copy_visible( inImage ) 
    redLayer = gimp.Layer( inImage, "ColorBlindRedLayer", inImage.width, inImage.height, RGBA_IMAGE, layerOpacity, ADDITION_MODE) 
    inImage.add_layer( redLayer )
    floatingSel = pdb.gimp_edit_paste( redLayer, False )
    pdb.gimp_floating_sel_anchor( floatingSel )
    monochrome = 0 #FALSE
    rr_gain = channelMixerIntensity
    rg_gain = 0.0
    rb_gain = 0.0
    gr_gain = 0.0
    gg_gain = 0.0
    gb_gain = 0.0
    br_gain = 0.0
    bg_gain = 0.0  
    bb_gain = 0.0
    pdb.plug_in_colors_channel_mixer( inImage, redLayer, monochrome, rr_gain, rg_gain, rb_gain, gr_gain, gg_gain, gb_gain, br_gain, bg_gain, bb_gain )
    pdb.gimp_image_undo_group_end( inImage )

register(
  "python-fu-photolab-redlayer",
  Photolab_redlayer_description,
  Photolab_redlayer_help,
  "Raymond Ostertag",
  "GPL License",
  "2009",
  _("Add/Remove red layer"),
  "*",
  Standalone_parameters + Photolab_redlayer_parameters,
  [],
  python_fu_photolab_redlayer,
  menu="<Image>/Colors"+"/"+_("Colorblind tools"),
  domain=("gimp20-photolab", locale_directory)   
  )

main()
